@@ -45,7 +45,7 @@ MainWindow::MainWindow(QWidget *parent) :
     zcode = new QString();  //graph parameter
     wfo = new QString();    //graph parameter
     doc = new QDomDocument("document"); //will be the xml document object
-	justStarted = true;
+	mostRecentHome = HOME_1;
 
     manager = new QNetworkAccessManager(this);
     mapper = new QSignalMapper(this);
@@ -62,7 +62,15 @@ MainWindow::MainWindow(QWidget *parent) :
     /*signal that the UI has finished setting up, and start the
       dialog for getting a zip code from the user*/
 	connect(this, SIGNAL(uiReady()), this, SLOT(changeZip()), Qt::QueuedConnection);
-	emit uiReady();
+
+	if(settings->value("default") == HOME_1){
+		changeZip(settings->value("home1", "").toString().toStdString().c_str());
+	}else if(settings->value("default") == HOME_2){
+		changeZip(settings->value("home2", "").toString().toStdString().c_str());
+		mostRecentHome = HOME_2;
+	}else{
+		emit uiReady();
+	}
 }
 
 
@@ -72,9 +80,12 @@ MainWindow::MainWindow(QWidget *parent) :
   at startup time
   */
 void MainWindow::setSettings(){
-	SettingsDialog sd(&settings->value("home1", ""),
-					  &settings->value("home2", ""),
-					  &settings->value("default", 0), this);
+	QVariant home1, home2, defaultHome;
+	home1 = settings->value("home1", "");
+	home2 = settings->value("home2", "");
+	defaultHome = settings->value("default", 0);
+	SettingsDialog sd(home1, home2,  defaultHome, this);
+
     sd.exec();
     sd.deleteLater();
 
@@ -153,22 +164,18 @@ void MainWindow::setDomDocument(QString *reply){
   into a text box and the executes a request to the server for
   an XML file.
   */
-void MainWindow::changeZip(){
+void MainWindow::changeZip(const char zipcode[]){
     zipCache = zipCode;
     zipCode.clear();
 
-	if(!justStarted || settings->value("default") == 0){
+	if(zipcode != 0){
+		zipCode = zipcode;
+	}else{
 		Dialog *d = new Dialog(this);
 		d->exec();
 		d->deleteLater();
 		zipCode = d->getZip();
-	}else if(settings->value("default") == 1){
-		zipCode = settings->value("home1", "").toString();
-	}else if(settings->value("default") == 2){
-		zipCode = settings->value("home2", "").toString();
 	}
-	justStarted = false;
-
 
     if(!zipCode.isEmpty()){
         zipCode.truncate(5);
@@ -185,6 +192,19 @@ void MainWindow::changeZip(){
     }
 }
 
+/**
+  slot for initiating a changeZip() to the users other home
+  */
+void MainWindow::otherHome(){
+	if(mostRecentHome == HOME_1 && settings->value("home2", "").toString() != ""){
+		changeZip( settings->value("home2", "").toString().toStdString().c_str());
+		mostRecentHome = HOME_2;
+	}else if(mostRecentHome == HOME_2 && settings->value("home1", "").toString() != ""){
+		changeZip( settings->value("home1", "").toString().toStdString().c_str());
+		mostRecentHome = HOME_1;
+	}
+}
+
 
 /**
   get the "wfo" (weather forecast office) parameter
@@ -199,6 +219,7 @@ void MainWindow::parse_for_wfo(QDomElement *docEle){
 
 /**
   Takes a DomElement and creates a QList of QStrings containing the temperatures
+  !!You must delete the return value yourself
   */
 QList<QString*>* MainWindow::parse_for_temps(QDomElement *docEle){
 
@@ -236,6 +257,7 @@ QList<QString*>* MainWindow::parse_for_temps(QDomElement *docEle){
   National Weather service does not have a consistent xml feed. Sometimes the days
   of the week are the second 'time-layout' tag, sometimes they're the third, we have
   have to search for them
+  !!You must delete the return value yourself
   */
 QList<QString*>* MainWindow::parse_for_days(QDomElement *docEle){
     QDomNodeList weekList = docEle->elementsByTagName("time-layout");
@@ -257,6 +279,7 @@ QList<QString*>* MainWindow::parse_for_days(QDomElement *docEle){
   Parse the xml file for the city that represents the zipcode. Not all
   xml files will contains the same city zipcode (one of two choices...so far)
   so we need to see which one it has
+  !!You must delete the return value yourself
   */
 QString* MainWindow::parse_for_city(QDomElement *docEle){
     QDomNodeList locList(docEle->firstChild().nextSibling().toElement().elementsByTagName("location"));
@@ -274,16 +297,17 @@ QString* MainWindow::parse_for_city(QDomElement *docEle){
 
 /**
   Parse the dom document for the precipitations and return them
-  in a QList of QStrings. Also format the string's to include
+  in a new QList of QStrings. Also format the string's to include
   "Precipitation: " so setting label's is easier later
+  !!You must delete the return value yourself
   */
 QList<QString*>* MainWindow::parse_for_precip(QDomElement *docEle){
-    QDomNodeList* precipList = &docEle->elementsByTagName("probability-of-precipitation").at(0).toElement().elementsByTagName("value");
+	QDomNodeList precipList = docEle->elementsByTagName("probability-of-precipitation").at(0).toElement().elementsByTagName("value");
     QList<QString*>* returnPrecips = new QList<QString*>();
 
-    for(int i = 0 ; i < precipList->size(); i++){
-        QString str("Precipitation: " + precipList->at(i).toElement().text() + "%");
-        if(precipList->at(i).toElement().text().isEmpty()){
+	for(int i = 0 ; i < precipList.size(); i++){
+		QString str("Precipitation: " + precipList.at(i).toElement().text() + "%");
+		if(precipList.at(i).toElement().text().isEmpty()){
             str = "Precipitation: Effectively 0%";
         }
         returnPrecips->append(new QString(str));
@@ -495,9 +519,7 @@ void MainWindow::setFIcon(){
 void MainWindow::deleteCache(){
     for(int i = 0; i < 13; i++){
 		delete iconCache[i];
-    }
-    for(int i = 0; i < 13; i++){
-        iconCache[i] = new QPixmap();
+		iconCache[i] = new QPixmap();
     }
 }
 
@@ -516,11 +538,7 @@ void MainWindow::detailWindow(int day){
 
     int dayVar = day;
     int nightVar = day;
-    if(weekList->at(day)->contains(" Night")){
-        dayVar = day-1;
-    }else{
-        nightVar = day+1;
-    }
+	weekList->at(day)->contains("Night") ? dayVar = day-1 : nightVar = day+1;
 
     //get the info from the xml file
     QString offset = QString::number(dayVar*12);
@@ -530,12 +548,12 @@ void MainWindow::detailWindow(int day){
     QString precip(*precipList->at(day));
     QString nightSummary(wordedList.at(nightVar).toElement().text());
     QString daySummary(wordedList.at(dayVar).toElement().text());
+	QString nightIcon = iconList.at(nightVar).toElement().text();
+	QString dayIcon = iconList.at(dayVar).toElement().text();
 
-
-    //create a window to show it
-    StackedWindow *sw = new StackedWindow(latlon, wfo, zcode,
-                                          &offset, iconCache[dayVar], &iconList.at(dayVar).toElement().text(),
-                                          iconCache[nightVar], &iconList.at(nightVar).toElement().text(), this);
+	StackedWindow *sw = new StackedWindow(*latlon, *wfo, *zcode,
+										  offset, *iconCache[dayVar],dayIcon,
+										  *iconCache[nightVar], nightIcon, this);
 #ifdef Q_WS_MAEMO_5
     sw->setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif
