@@ -1,34 +1,31 @@
 #include "settingsdialog.h"
 #include "ui_settingsdialog.h"
 
-SettingsDialog::SettingsDialog(QVariant *home1, QVariant *home2, QVariant *defaultHome, QWidget *parent) :
+SettingsDialog::SettingsDialog(QVariant& home1, QVariant& home2, QVariant& defaultHome, QWidget *parent) :
     QDialog(parent),
     ui(new Ui::SettingsDialog)
 {
     ui->setupUi(this);
-    ui->home1Entry->setText(home1->toString());
+	ui->home1Entry->setText(home1.toString());
     ui->home1Entry->setInputMethodHints(Qt::ImhDigitsOnly);
-    ui->home2Entry->setText(home2->toString());
+	ui->home2Entry->setText(home2.toString());
     ui->home2Entry->setInputMethodHints((Qt::ImhDigitsOnly));
-    ui->activeComboBox->setCurrentIndex(defaultHome->toInt());
+	ui->activeComboBox->setCurrentIndex(defaultHome.toInt());
 
-    ui->line->setPalette(QApplication::palette().highlight().color());
-    ui->line_2->setPalette(QApplication::palette().highlight().color());
-    ui->line_3->setPalette(QApplication::palette().highlight().color());
+	this->home1 = &home1;
+	this->home2 = &home2;
+	this->defaultHome = &defaultHome;
 
-    this->home1 = new QVariant(*home1);
-    this->home2 = new QVariant(*home2);
-    this->defaultHome = new QVariant(*defaultHome);
+//	this->home1 = new QVariant(home1);
+//	this->home2 = new QVariant(home2);
+//	this->defaultHome = new QVariant(defaultHome);
 
     connect(this, SIGNAL(accepted()), this, SLOT(setValues()));
 }
 
 SettingsDialog::~SettingsDialog()
 {
-    delete ui;
-    delete home1;
-    delete home2;
-    delete defaultHome;
+	delete ui;
 }
 
 void SettingsDialog::resizeEvent(QResizeEvent *event){
@@ -46,13 +43,13 @@ void SettingsDialog::setValues(){
 }
 
 QVariant* SettingsDialog::getHome1(){
-    return home1;
+	return home1;
 }
 
 QVariant* SettingsDialog::getHome2(){
-    return home2;
+	return home2;
 }
 
 QVariant* SettingsDialog::getDefaultHome(){
-    return defaultHome;
+	return defaultHome;
 }
