@@ -13,7 +13,7 @@ class SettingsDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit SettingsDialog(QVariant* home1, QVariant* home2, QVariant* defaultHome, QWidget *parent = 0);
+	explicit SettingsDialog(QVariant& home1, QVariant& home2, QVariant& defaultHome, QWidget *parent = 0);
     ~SettingsDialog();
     QVariant* getHome1();
     QVariant* getHome2();
@@ -25,9 +25,9 @@ protected:
 
 private:
     Ui::SettingsDialog *ui;
-    QVariant* home1;
-    QVariant* home2;
-    QVariant* defaultHome;
+	QVariant* home1;
+	QVariant* home2;
+	QVariant* defaultHome;
 
 private slots:
     void setValues();
