@@ -7,6 +7,7 @@
 #include <QUrl>
 #include <QNetworkReply>
 #include <QSignalMapper>
+#include <QPropertyAnimation>
 #include <QLabel>
 #include "graphframe.h"
 
@@ -19,9 +20,9 @@ class StackedWindow : public QMainWindow
     Q_OBJECT
 
 public:
-    explicit StackedWindow(QString* latlong, QString* wso, QString* zcode,
-                           QString* offset, QPixmap* dayIcon, QString* dayURL,
-                           QPixmap* nightIcon, QString* nightURL, QWidget *parent = 0);
+	explicit StackedWindow(QString& latlong, QString& wso, QString& zcode,
+						   QString& offset, QPixmap& dayIcon, QString& dayURL,
+						   QPixmap& nightIcon, QString& nightURL, QWidget *parent = 0);
     ~StackedWindow();
     void setInfo(QString &day, QString &hi, QString &lo, QString &precip, QString &dayFor, QString &nightFor);
 
@@ -41,10 +42,11 @@ private:
 	QString* wfo;
 	QString* latlong;
 	QString* offset;
+	QString* zcode;
+	GraphFrame* tempFrame;
+	GraphFrame* precipFrame;
 	GraphFrame* snowFrame;
 	GraphFrame* rainFrame;
-
-    void colorize(QLabel* label);
 };
 
 #endif // STACKEDWINDOW_H
